@@ -2,13 +2,17 @@
 from enum import Enum
 from hashlib import sha256
 from types import TracebackType
-from typing import List, Optional, Type
+from typing import Any, Optional
 
 import aiohttp
 from aiohttp import ClientSession, ServerDisconnectedError
 
 from intellifire4py.const import IntellifireCommand, _log
-from intellifire4py.control import ApiCallException, InputRangeException, LoginException
+from intellifire4py.exceptions import (
+    ApiCallException,
+    InputRangeException,
+    LoginException,
+)
 from intellifire4py.model import IntellifireFireplace, IntellifireFireplaces
 
 
@@ -19,6 +23,9 @@ class IntellifireSendMode(Enum):
     CLOUD = "cloud"
 
 
+# logging.basicConfig(level=logging.DEBUG)
+
+
 class IntellifireControlAsync:
     """Hacked together control API for intellifire modules."""
 
@@ -49,18 +56,18 @@ class IntellifireControlAsync:
             self.__client = aiohttp.ClientSession(cookies=self._cookie)
         return self.__client
 
-    async def close(self) -> None:
+    async def close(self) -> Any:
         """Close socket."""
         return await self._client.close()
 
-    async def __aenter__(self) -> "Client":  # type: ignore
+    async def __aenter__(self) -> "Client":  # type: ignore # noqa: F821
         """Magic Enter Function."""
         # This function may not be needed at all 🤷️
         return self
 
     async def __aexit__(
         self,
-        exc_type: Optional[Type[BaseException]],
+        exc_type: Optional[type[BaseException]],
         exc_val: Optional[BaseException],
         exc_tb: Optional[TracebackType],
     ) -> Optional[bool]:
@@ -78,7 +85,7 @@ class IntellifireControlAsync:
                 if resp.status != 204:
                     raise LoginException()
 
-                self._cookie = resp.cookies  # type: ignore
+                self._cookie = resp.cookies
                 self.is_logged_in = True
                 _log.info("Success - Logged into IFTAPI")
 
@@ -94,7 +101,7 @@ class IntellifireControlAsync:
         if not self.is_logged_in:
             raise LoginException("Not Logged In")
 
-    async def get_username(self) -> str:
+    async def get_username(self) -> Any:
         """Call to iftapi.net to extract the username based on cookie information."""
         await self._login_check()
         async with self._client.get(
@@ -114,7 +121,7 @@ class IntellifireControlAsync:
         self.default_fireplace = fireplaces[0]
         _log.debug(f"configure default fireplace: {self.default_fireplace.serial}")
 
-    async def get_locations(self) -> List:
+    async def get_locations(self) -> list:
         """Enumerate configured locations that a user has access to.
 
         'location_id' can be used to discovery fireplaces
@@ -127,7 +134,7 @@ class IntellifireControlAsync:
             json_data = await resp.json()
             return json_data["locations"]  # type: ignore
 
-    async def get_fireplaces(self, *, location_id: str) -> List[IntellifireFireplace]:
+    async def get_fireplaces(self, *, location_id: str) -> list[IntellifireFireplace]:
         """Get fireplaces at a location with associated API keys!."""
         await self._login_check()
         async with self._client.get(
@@ -136,7 +143,7 @@ class IntellifireControlAsync:
             json_data = await resp.json()
             return IntellifireFireplaces(**json_data).fireplaces
 
-    async def get_challenge(self) -> str:
+    async def get_challenge(self) -> Any:
         """Hit the local challenge endpoint."""
         async with self._client.get(f"http://{self._ip}/get_challenge") as resp:
             ret = await resp.text()
@@ -193,6 +200,8 @@ class IntellifireControlAsync:
             )
             if resp.status == 404:
                 _log.warning(f"Failed to post: {url}{data}")
+            if resp.status == 422:
+                _log.warning(f"422 Code on: {url}{data}")
 
     async def send_command(
         self,
@@ -278,6 +287,16 @@ class IntellifireControlAsync:
             fireplace=fireplace, command=IntellifireCommand.FAN_SPEED, value=speed
         )
 
+    async def soft_reset(self, *, fireplace: IntellifireFireplace) -> None:
+        """Send Soft Reset Command."""
+        if self.send_mode == IntellifireSendMode.LOCAL:
+            _log.warning(
+                "soft_reset command only will work via cloud control"
+            )  # I haven't been able to figure out if there is a local version of this command
+        await self.send_command(
+            fireplace=fireplace, command=IntellifireCommand.SOFT_RESET, value=1
+        )
+
     async def fan_off(self, *, fireplace: IntellifireFireplace) -> None:
         """Turn fan off."""
         await self.send_command(
@@ -338,14 +357,14 @@ class IntellifireControlAsync:
     @property
     def user(self) -> str:
         """Get user cookie."""
-        return str(self._cookie.get("user").value)
+        return str(self._cookie.get("user").value)  # type: ignore
 
     @property
     def auth_cookie(self) -> str:
         """Get Auth Cookie."""
-        return str(self._cookie.get("auth_cookie").value)
+        return str(self._cookie.get("auth_cookie").value)  # type: ignore
 
     @property
     def web_client_id(self) -> str:
         """Get web client id."""
-        return str(self._cookie.get("web_client_id").value)
+        return str(self._cookie.get("web_client_id").value)  # type: ignore
