@@ -9,6 +9,8 @@ from typing import List
 
 from pydantic import BaseModel, Field
 
+from intellifire4py.const import IntellifireErrorCode
+
 
 class IntellifirePollData(BaseModel):
     name: str
@@ -30,7 +32,7 @@ class IntellifirePollData(BaseModel):
     has_thermostat: bool = Field(alias="feature_thermostat")
     has_power_vent: bool = Field(alias="power_vent")
     has_fan: bool = Field(alias="feature_fan")
-    errors: List[int]
+    errors: list[int]
     fw_version: str
     fw_ver_str: str
     downtime: int
@@ -51,6 +53,15 @@ class IntellifirePollData(BaseModel):
     def thermostat_setpoint_f(self) -> float:
         return (self.raw_thermostat_setpoint / 100 * 9 / 5) + 32
 
+    @property
+    def error_codes(self) -> list[IntellifireErrorCode]:
+        return [IntellifireErrorCode(i) for i in self.errors]
+
+    @property
+    def error_codes_string(self) -> str:
+        """Assembled error codes into a formatted string"""
+        return ", ".join([code.name for code in self.error_codes])
+
 
 class UDPResponse(BaseModel):
     mac: str
@@ -75,7 +86,7 @@ class IntellifireLocationDetails(BaseModel):
 
 
 class IntellifireLocations(BaseModel):
-    locations: List[IntellifireLocationDetails]
+    locations: list[IntellifireLocationDetails]
     email_notifications_enabled: int
 
 
@@ -89,4 +100,4 @@ class IntellifireFireplace(BaseModel):
 
 class IntellifireFireplaces(BaseModel):
     location_name: str
-    fireplaces: List[IntellifireFireplace]
+    fireplaces: list[IntellifireFireplace]
